# pytest-playbook

Pytest plugin for reading playbooks. Supports the LISAv3 framework.

See the [documentation][] for more information, and the LISAv3 [`README.md`][]
for notices.

[documentation]: https://microsoft.github.io/lisa/modules/playbook.html
[`README.md`]: https://github.com/microsoft/lisa/blob/andschwa/pytest/README.md
